@@ -62,7 +62,7 @@
 #include <Plasma/Wallpaper>
 #include <Plasma/WindowEffects>
 
-#include <Nepomuk2/ResourceManager>
+#include <Nepomuk/ResourceManager>
 
 #ifdef Q_WS_X11
 #include <X11/Xlib.h>
@@ -90,9 +90,10 @@ PlasmaApp::PlasmaApp()
     KGlobal::locale()->insertCatalog("libplasma");
     KGlobal::locale()->insertCatalog("plasma-device");
 
+    setenv("PLASMA_CUSTOM_PREFIX_PATHS", "platformcontents/widget/tablet/:platformcontents/widget/touch/:platformcontents/widget/generic/:contents/", 1);
     KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
 
-    Nepomuk2::ResourceManager::instance()->init();
+    Nepomuk::ResourceManager::instance()->init();
 
     qmlRegisterType<PanelProxy>("org.kde.plasma.deviceshell", 0, 1, "DevicePanel");
     qmlRegisterUncreatableType<ContainmentProperties>("org.kde.plasma.deviceshell", 0, 1, "ContainmentProperties", "ContainmentProperties is just a type holder");
@@ -316,6 +317,8 @@ void PlasmaApp::changeContainment(Plasma::Containment *containment)
     QDeclarativeProperty containmentProperty(m_homeScreen, "activeContainment");
     containmentProperty.write(QVariant::fromValue(static_cast<QGraphicsWidget*>(containment)));
 
+    m_oldContainment = m_currentContainment;
+
     m_currentContainment = containment;
 }
 
